@@ -1,4 +1,4 @@
-import cofffee.color as c
+import color as c
 
 # green tea
 
